@@ -32,6 +32,7 @@ import (
 
 	apiv1 "github.com/stefanprodan/timoni/api/v1alpha1"
 	"github.com/stefanprodan/timoni/internal/engine"
+	"github.com/stefanprodan/timoni/internal/engine/fetcher"
 	"github.com/stefanprodan/timoni/internal/flags"
 	"github.com/stefanprodan/timoni/internal/runtime"
 )
@@ -163,16 +164,19 @@ func runApplyCmd(cmd *cobra.Command, args []string) error {
 	ctxPull, cancel := context.WithTimeout(context.Background(), rootArgs.timeout)
 	defer cancel()
 
-	fetcher := engine.NewFetcher(
-		ctxPull,
-		applyArgs.module,
-		version,
-		tmpDir,
-		rootArgs.cacheDir,
-		applyArgs.creds.String(),
-		rootArgs.registryInsecure,
-	)
-	mod, err := fetcher.Fetch()
+	f, err := fetcher.New(ctxPull, fetcher.Options{
+		Source:       applyArgs.module,
+		Version:      version,
+		Destination:  tmpDir,
+		CacheDir:     rootArgs.cacheDir,
+		Creds:        applyArgs.creds.String(),
+		Insecure:     rootArgs.registryInsecure,
+		DefaultLocal: true,
+	})
+	if err != nil {
+		return err
+	}
+	mod, err := f.Fetch()
 	if err != nil {
 		return err
 	}
@@ -182,7 +186,7 @@ func runApplyCmd(cmd *cobra.Command, args []string) error {
 		cuectx,
 		applyArgs.name,
 		*kubeconfigArgs.Namespace,
-		fetcher.GetModuleRoot(),
+		f.GetModuleRoot(),
 		applyArgs.pkg.String(),
 	)
 
@@ -217,7 +221,7 @@ func runApplyCmd(cmd *cobra.Command, args []string) error {
 
 	buildResult, err := builder.Build()
 	if err != nil {
-		return describeErr(fetcher.GetModuleRoot(), "build failed", err)
+		return describeErr(f.GetModuleRoot(), "build failed", err)
 	}
 
 	finalValues, err := builder.GetDefaultValues()
