@@ -24,7 +24,7 @@ import (
 
 	"cuelang.org/go/cue/cuecontext"
 	"cuelang.org/go/pkg/strings"
-	"github.com/fluxcd/pkg/ssa"
+	ssautil "github.com/fluxcd/pkg/ssa/utils"
 	"github.com/google/go-containerregistry/pkg/name"
 	cp "github.com/otiai10/copy"
 	"github.com/spf13/cobra"
@@ -32,6 +32,7 @@ import (
 
 	apiv1 "github.com/stefanprodan/timoni/api/v1alpha1"
 	"github.com/stefanprodan/timoni/internal/engine"
+	"github.com/stefanprodan/timoni/internal/engine/fetcher"
 	"github.com/stefanprodan/timoni/internal/flags"
 )
 
@@ -92,16 +93,19 @@ func runVetModCmd(cmd *cobra.Command, args []string) error {
 	ctxPull, cancel := context.WithTimeout(context.Background(), rootArgs.timeout)
 	defer cancel()
 
-	fetcher := engine.NewFetcher(
-		ctxPull,
-		vetModArgs.path,
-		apiv1.LatestVersion,
-		tmpDir,
-		rootArgs.cacheDir,
-		"",
-		rootArgs.registryInsecure,
-	)
-	mod, err := fetcher.Fetch()
+	f, err := fetcher.New(ctxPull, fetcher.Options{
+		Source:       vetModArgs.path,
+		Version:      apiv1.LatestVersion,
+		Destination:  tmpDir,
+		CacheDir:     rootArgs.cacheDir,
+		Insecure:     rootArgs.registryInsecure,
+		DefaultLocal: true,
+	})
+	if err != nil {
+		return err
+	}
+
+	mod, err := f.Fetch()
 	if err != nil {
 		return err
 	}
@@ -126,7 +130,7 @@ func runVetModCmd(cmd *cobra.Command, args []string) error {
 		cuectx,
 		vetModArgs.name,
 		*kubeconfigArgs.Namespace,
-		fetcher.GetModuleRoot(),
+		f.GetModuleRoot(),
 		vetModArgs.pkg.String(),
 	)
 
@@ -152,7 +156,7 @@ func runVetModCmd(cmd *cobra.Command, args []string) error {
 
 	buildResult, err := builder.Build(tags...)
 	if err != nil {
-		return describeErr(fetcher.GetModuleRoot(), "validation failed", err)
+		return describeErr(f.GetModuleRoot(), "validation failed", err)
 	}
 
 	applySets, err := builder.GetApplySets(buildResult)
@@ -175,7 +179,7 @@ func runVetModCmd(cmd *cobra.Command, args []string) error {
 
 	for _, object := range objects {
 		log.Info(fmt.Sprintf("%s %s",
-			colorizeSubject(ssa.FmtUnstructured(object)), colorizeInfo("valid resource")))
+			colorizeSubject(ssautil.FmtUnstructured(object)), colorizeInfo("valid resource")))
 	}
 
 	images, err := builder.GetContainerImages(buildResult)
