@@ -22,7 +22,9 @@ import (
 	"os"
 	"path/filepath"
 	"reflect"
+	"regexp"
 	"slices"
+	"strings"
 
 	"cuelang.org/go/cue"
 	"cuelang.org/go/cue/ast"
@@ -36,7 +38,7 @@ const (
 	defaultPackage      = "main"
 	defaultValuesFile   = "values.cue"
 	defaultSchemaFile   = "timoni.schema.cue"
-	defaultDevelVersion = "0.0.0-devel"
+	DefaultDevelVersion = "0.0.0-devel"
 
 	// The default Kubernetes version must be kept in sync with go.mod.
 	defaultKubeVersion = "1.27.5"
@@ -66,7 +68,7 @@ func NewModuleBuilder(ctx *cue.Context, name, namespace, moduleRoot, pkgName str
 		pkgPath:       moduleRoot,
 		name:          name,
 		namespace:     namespace,
-		moduleVersion: defaultDevelVersion,
+		moduleVersion: DefaultDevelVersion,
 		kubeVersion:   defaultKubeVersion,
 	}
 
@@ -90,6 +92,10 @@ func (b *ModuleBuilder) MergeValuesFile(overlays [][]byte) error {
 		return err
 	}
 
+	if err := finalVal.Err(); err != nil {
+		return err
+	}
+
 	cueGen := fmt.Sprintf("package %s\n%s: %v", b.pkgName, apiv1.ValuesSelector, finalVal)
 
 	// overwrite the values.cue file with the merged values
@@ -111,6 +117,10 @@ func (b *ModuleBuilder) WriteValuesFileWithDefaults(val cue.Value) error {
 		return err
 	}
 
+	if err := finalVal.Err(); err != nil {
+		return err
+	}
+
 	cueGen := fmt.Sprintf("package %s\n%s: %v", b.pkgName, apiv1.ValuesSelector, finalVal)
 
 	// overwrite the values.cue file with the merged values
@@ -305,3 +315,60 @@ func (b *ModuleBuilder) GetContainerImages(value cue.Value) ([]string, error) {
 
 	return images, nil
 }
+
+// GetConfigDoc extracts the config structure from the module.
+func (b *ModuleBuilder) GetConfigDoc(value cue.Value) ([][]string, error) {
+	cfgValues := value.LookupPath(cue.ParsePath(apiv1.ConfigValuesSelector.String()))
+	if cfgValues.Err() != nil {
+		return nil, fmt.Errorf("lookup %s failed: %w", apiv1.ConfigValuesSelector, cfgValues.Err())
+	}
+
+	labelDomain := regexp.MustCompile(`^([a-zA-Z0-9-_.]+)?(".+")?$`)
+
+	var rows [][]string
+	configDataInfo := func(v cue.Value) bool {
+		var row []string
+		var noDoc bool
+		var doc string
+
+		for _, d := range v.Doc() {
+			if line := len(d.List) - 1; line >= 0 {
+				switch d.List[line].Text {
+				case "// +nodoc":
+					noDoc = true
+					break
+				}
+			}
+
+			doc += d.Text()
+			doc = strings.ReplaceAll(doc, "\n", " ")
+			doc = strings.ReplaceAll(doc, "+required", "")
+			doc = strings.ReplaceAll(doc, "+optional", "")
+		}
+
+		if !noDoc {
+			defaultVal, _ := v.Default()
+			valueBytes, _ := defaultVal.MarshalJSON()
+			valueType := strings.ReplaceAll(v.IncompleteKind().String(), "|", "\\|")
+
+			value := strings.ReplaceAll(string(valueBytes), "\":", "\": ")
+			value = strings.ReplaceAll(value, "\":[", "\": [")
+			value = strings.ReplaceAll(value, "},", "}, ")
+			value = strings.ReplaceAll(value, "|", "\\|")
+
+			field := strings.Replace(v.Path().String(), "timoni.instance.config.", "", 1)
+			match := labelDomain.FindStringSubmatch(field)
+
+			row = append(row, fmt.Sprintf("`%s:`", strings.ReplaceAll(match[1], ".", ": ")+match[2]))
+			row = append(row, fmt.Sprintf("`%s`", valueType))
+			row = append(row, fmt.Sprintf("`%s`", value))
+			row = append(row, fmt.Sprintf("%s", doc))
+			rows = append(rows, row)
+		}
+
+		return true
+	}
+
+	cfgValues.Walk(configDataInfo, nil)
+	return rows, nil
+}
